"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = universalDotenv;
Object.defineProperty(exports, "expand", {
  enumerable: true,
  get: function () {
    return _expand.default;
  }
});

var _package = require("../package");

var _expand = _interopRequireDefault(require("./expand"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const allowedEnvs = ['development', 'test', 'production'];

function universalDotenv({
  types: {
    valueToNode,
    logicalExpression,
    identifier
  }
}) {
  return {
    name: _package.name,

    pre() {
      this.NODE_ENV = allowedEnvs.includes(process.env.NODE_ENV) ? process.env.NODE_ENV : 'development';
      this.values = (0, _expand.default)(this.NODE_ENV);
    },

    visitor: {
      MemberExpression(node) {
        if (!node.get('object').matchesPattern('process.env')) {
          return;
        }

        const {
          value: key
        } = node.toComputedKey();

        if (key === 'NODE_ENV') {
          node.replaceWith(valueToNode(this.NODE_ENV));
        } else if (Object.prototype.hasOwnProperty.call(this.values, key)) {
          node.replaceWith(logicalExpression('||', identifier(`process.env.${key}`), valueToNode(this.values[key])));
        }
      }

    }
  };
}
//# sourceMappingURL=index.js.map